@@ -6,7 +6,7 @@ JSON::Validator - Validate data against a JSON schema
 
 =head1 VERSION
 
-0.60
+0.61
 
 =head1 SYNOPSIS
 
@@ -140,7 +140,7 @@ use constant DEBUG => $ENV{JSON_VALIDATOR_DEBUG} || $ENV{SWAGGER2_DEBUG} || 0;
 use constant WARN_ON_MISSING_FORMAT => $ENV{JSON_VALIDATOR_WARN_ON_MISSING_FORMAT}
   || $ENV{SWAGGER2_WARN_ON_MISSING_FORMAT} ? 1 : 0;
 
-our $VERSION = '0.60';
+our $VERSION = '0.61';
 our @EXPORT_OK = qw( validate_json );
 
 my $HTTP_SCHEME_RE = qr{^https?:};
@@ -729,12 +729,7 @@ sub _validate_type_array {
   }
   elsif (ref $schema->{items} eq 'HASH') {
     for my $i (0 .. @$data - 1) {
-      if ($schema->{items}{properties}) {
-        push @errors, $self->_validate_type_object($data->[$i], "$path/$i", $schema->{items});
-      }
-      else {
-        push @errors, $self->_validate($data->[$i], "$path/$i", $schema->{items});
-      }
+      push @errors, $self->_validate($data->[$i], "$path/$i", $schema->{items});
     }
   }
 
